# Welcome to Fennel

## The modern realtime feature engineering platform

---

Fennel is a modern realtime feature engineering platform and has been architected from the ground up in service of three design goals.

## Fennel's Three Design Goals
1. Easy to install, learn & use - using familiar Python instead of special DSLs, simple but powerful abstractions, zero dependency installation, fully managed with zero ops, same code working for both realtime and non-realtime cases and more to make using Fennel as easy as possible
2. Reduce cloud costs - being significantly lower on cloud costs compared to other alternatives by squeezing as much out of cloud hardware as possible [See  for how Fennel does this]
3. Encourage best practices - native support for testing, CI/CD, versioned & immutable features, lineage tracking, enforcement of code ownership, data expectations, read/write compute separation and more to help you bring best engineering practices to feature engineering too

As a result of the architectural philosophy, Fennel ends up unlocking the following benefits:

## Benefits of Fennel

1. Higher development velocity: more iterations can be done in the same time leading to higher business value
2. Lower total costs of ownership: Fennel saves costs across the board - cloud spend, bandwidth of engineers that would have gone in ops, and bandwidth of data scientists by making them more productive
3. Higher business value via realtime features: unlocking realtime and other sophisticated features leads to better models with higher business gains
4. Healthier codebase & more reliable features: engineering best practices like testing, immutability, code ownership etc improve code maintainability leading to more reliable data & feature

## Getting Started With Fennel

[Start](https://docs.fennel.ai/getting-started/quickstart) here if you want to directly dive deep into an end-to-end example.

Or if you are not in a hurry, read about the main [concepts](https://docs.fennel.ai/overview/concepts) first followed by some more details about the [datasets](https://docs.fennel.ai/datasets/overview)  and [featuresets](https://docs.fennel.ai/featuresets/overview-wip) . And if you run into any issues or have any questions/feedback, you're welcome to jump into our slack channel to directly chat with the engineers building it.
We, the team behind Fennel, have thoroughly enjoyed building Fennel and hope learning and using Fennel brings as much delight to you as well!